from django.conf import settings

# Filesystem location to store protected media
PROTECTED_MEDIA_ROOT = getattr(
    settings, "PROTECTED_MEDIA_ROOT", "%s/protected/" % settings.BASE_DIR
)

# The URL prefix used by protected media
PROTECTED_MEDIA_URL = getattr(
    settings, "PROTECTED_MEDIA_URL", "protected/"
)

# An alternative prefix to use with servers like Nginx, where we want to
# disambiguate requests routed to Django and internal redirects to serve
# files.
PROTECTED_MEDIA_LOCATION_PREFIX = getattr(
    settings, "PROTECTED_MEDIA_LOCATION_PREFIX", PROTECTED_MEDIA_URL
)

# The server used to server the media. Django will always perform the
# authorisation.
PROTECTED_MEDIA_SERVER = getattr(
    settings, "PROTECTED_MEDIA_SERVER", "django"
)

# Controls whether the protected media are served as downloads. If True, the
# Content-Disposition flag will be set.
PROTECTED_MEDIA_AS_DOWNLOADS = False




# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import mimetypes
import os

from django.contrib.auth.decorators import login_required
from django.http import HttpResponse
from django.views.static import serve
from os.path import basename

from .utils import server_header
from .settings import PROTECTED_MEDIA_LOCATION_PREFIX, PROTECTED_MEDIA_ROOT


@login_required
def protected_view(request, path, server="django", as_download=False):
    if server != "django":
        mimetype, encoding = mimetypes.guess_type(path)
        response = HttpResponse()
        response["Content-Type"] = mimetype
        if encoding:
            response["Content-Encoding"] = encoding

        if as_download:
            response["Content-Disposition"] = "attachment; filename={}".format(
                basename(path))

        response[server_header(server)] = os.path.join(
            PROTECTED_MEDIA_LOCATION_PREFIX, path
        ).encode("utf8")
    else:
        response = serve(
            request, path, document_root=PROTECTED_MEDIA_ROOT,
            show_indexes=False
        )

    return response



import os
from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-protected-media',
    version='1.0.1',
    packages=find_packages(),
    include_package_data=True,
    license='BSD License',
    description='A simple Django app to serve protected media',
    long_description=README,
    long_description_content_type='text/markdown',
    url='https://github.com/cobusc/django-protected-media/',
    author='Cobus Carstens',
    author_email='cobus.carstens@gmail.com',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 2.2',
        'Framework :: Django :: 3.0',
        'Framework :: Django :: 3.1',
        'Framework :: Django :: 4.0',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.core.files.storage import FileSystemStorage
from django.db import models

from .settings import PROTECTED_MEDIA_ROOT, PROTECTED_MEDIA_URL


class ProtectedFileSystemStorage(FileSystemStorage):
    """
    A class to manage protected files.
    We have to override the methods in the FileSystemStorage class which
    are decorated with cached_property for this class to work as intended.
    """
    def __init__(self, *args, **kwargs):
        kwargs["location"] = PROTECTED_MEDIA_ROOT
        kwargs["base_url"] = PROTECTED_MEDIA_URL
        super(ProtectedFileSystemStorage, self).__init__(*args, **kwargs)


class ProtectedFileField(models.FileField):
    def __init__(self, **kwargs):
        kwargs["storage"] = ProtectedFileSystemStorage()
        super(ProtectedFileField, self).__init__(**kwargs)


class ProtectedImageField(models.ImageField):
    def __init__(self, **kwargs):
        kwargs["storage"] = ProtectedFileSystemStorage()
        super(ProtectedImageField, self).__init__(**kwargs)
